@@ -1,10 +1,10 @@
-__version__ = "0.1"
+__version__ = "0.1.1"
 __git_commiter_name__ = "Arnon Yaari"
-__git_commiter_email__ = "wiggin15@yahoo.com"
+__git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'fc32ee4927a0b50994f618820d6c81c33dec7bfc'
-__git_head_subject__ = 'Finished release v0.1.'
+__git_head_hash__ = '317779be7e8265dca60adf0e0b10ddcd4b69c68d'
+__git_head_subject__ = 'Finished release v0.1.1.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
